#include <linux/module.h>
#include <linux/sched.h>

/* See commit v6.1-rc1~98^2~6 */

static int check_type(void)
{
	return TASK_FREEZABLE;
}

EXPORT_SYMBOL(check_type);
MODULE_LICENSE("GPL");
